@@ -1,8 +1,6 @@
 from foundry.core.graphics_page.GraphicsPage import GraphicsPage
 from foundry.core.graphics_set.GraphicsSet import GraphicsSet
-from foundry.core.palette import COLORS_PER_PALETTE
-from foundry.core.palette.Palette import Palette
-from foundry.core.palette.PaletteGroup import PaletteGroup
+from foundry.core.palette import COLORS_PER_PALETTE, Palette, PaletteGroup
 from foundry.core.player_animations import (
     PLAYER_FRAME_PAGE_OFFSET,
     PLAYER_FRAME_START,
