@@ -4,10 +4,10 @@ from PySide6.QtCore import QPoint
 from PySide6.QtGui import QColor, QImage, QPainter, Qt
 
 from foundry.core.graphics_set.GraphicsSet import GraphicsSet
-from foundry.core.palette import NESPalette
-from foundry.core.palette.PaletteGroup import PaletteGroup
+from foundry.core.palette import ColorPalette, PaletteGroup
+from foundry.core.tiles import MASK_COLOR
 from foundry.game.File import ROM
-from foundry.game.gfx.drawable import MASK_COLOR, apply_selection_overlay
+from foundry.game.gfx.drawable import apply_selection_overlay
 from foundry.game.gfx.drawable.Tile import Tile
 
 TSA_BANK_0 = 0 * 256
@@ -41,7 +41,7 @@ class Block:
     def __init__(
         self,
         block_index: int,
-        palette_group: tuple[tuple[int, ...], ...],
+        palette_group: PaletteGroup,
         graphics_set: GraphicsSet,
         tsa_data: bytes,
         mirrored: bool = False,
@@ -113,7 +113,7 @@ class Block:
     def _replace_transparent_with_background(self, image: QImage):
         # draw image on background layer, to fill transparent pixels
         background = image.copy()
-        color = NESPalette[self.palette_group[self.palette_index][0]]
+        color = ColorPalette.from_default()[self.palette_group[self.palette_index, 0]].to_qt()
         background.fill(color)
 
         _painter = QPainter(background)
