@@ -2,7 +2,7 @@ from typing import Protocol
 
 from attr import attrs
 
-from foundry.core.point.Point import Point, PointProtocol
+from foundry.core.geometry import Point
 
 
 class EnemyProtocol(Protocol):
@@ -13,12 +13,12 @@ class EnemyProtocol(Protocol):
     ----------
     type: int
         The type of enemy
-    point: PointProtocol
+    point: Point
         The point of the enemy
     """
 
     type: int
-    position: PointProtocol
+    position: Point
 
     def __bytes__(self) -> bytes:
         ...
@@ -37,12 +37,12 @@ class Enemy:
     ----------
     type: int
         The type of enemy
-    point: PointProtocol
+    point: Point
         The point of the enemy
     """
 
     type: int
-    position: PointProtocol
+    position: Point
 
     def __bytes__(self) -> bytes:
         return bytes([self.type, self.position.x, self.position.y])
