@@ -3,7 +3,7 @@ from json import loads
 from PySide6.QtCore import QRect
 
 from foundry import warp_definitions
-from foundry.core.point.Point import PointProtocol
+from foundry.core.geometry import Point
 from foundry.game.Definitions import Definition
 from foundry.game.gfx.objects.GeneratorObject import GeneratorObject
 from foundry.game.gfx.objects.LevelObject import GROUND, SCREEN_HEIGHT, SCREEN_WIDTH
@@ -68,15 +68,15 @@ class Jump(GeneratorObject):
 
     @property
     def definition(self) -> Definition:
-        with open(warp_definitions, "r") as f:
+        with open(warp_definitions) as f:
             return Definition(__root__=loads(f.read()))
 
     @property
-    def position(self) -> PointProtocol:
+    def position(self) -> Point:
         pass
 
     @position.setter
-    def position(self, position: PointProtocol) -> None:
+    def position(self, position: Point) -> None:
         pass
 
     def move_by(self, dx, dy):
