@@ -1,7 +1,7 @@
 from PySide6.QtCore import QPoint, QSize
 
 from foundry.core.graphics_set.GraphicsSet import GraphicsSet
-from foundry.core.palette.PaletteGroup import PaletteGroup
+from foundry.core.palette import PaletteGroup
 from foundry.game.File import ROM
 from foundry.game.gfx.drawable.Block import Block
 from foundry.game.gfx.objects.MapObject import MapObject
@@ -51,7 +51,7 @@ class WorldMap(LevelLike):
 
             block = Block(
                 world_position.tile(),
-                tuple(tuple(c for c in pal) for pal in self.palette_group),
+                self.palette_group,
                 self.graphics_set,
                 self.tsa_data,
             )
