@@ -229,7 +229,7 @@ class BlockArray(QWidget):
         for block_index in self.level_object.blocks:
             block = get_block(
                 block_index,
-                tuple(tuple(c for c in pal) for pal in self.level_object.palette_group),
+                self.level_object.palette_group,
                 self.level_object.graphics_set,
                 bytes(self.level_object.tsa_data),
             )
